@@ -75,27 +75,37 @@ class drFinder:
             endpos = self.targetEnd
 
         self.findpos = self.stc.FindText(self.findpos, endpos, findtext, findflags)
-
         if self.findpos == -1:
             if self.stc.FindText(self.targetStart, self.targetEnd, findtext, findflags) == -1:
                 if self.parent.prefs.enablefeedback:
                     drScrolledMessageDialog.ShowMessage(self.parent, ('Search string "' + findtext + '" not found.'), "DrPython Find")
                 else:
+                    #wx.MessageBox ('Search string "' + findtext + '" not found.', "DrPython Find", wx.ICON_INFORMATION)
                     self.parent.SetStatusText('NOT FOUND: ' + findtext, 2)
                 return
             if ((self.findpos >= doclength) or (self.findpos < 0)) and (doclength > 0):
                 self.lastposition = -1
                 if self.backwards:
                     msg = 'Start of document reached: "' + findtext + '".\nStart again from the end?'
-                    self.findpos = self.targetEnd
+                    fpos =  self.targetEnd
                 else:
                     msg = 'End of document reached: "' + findtext + '".\nStart again from the beginning?'
-                    self.findpos = self.targetStart
-                if self.parent.prefs.findreplaceautowrap:
-                    answer = wx.OK
+                    fpos =  self.targetStart
+                
+                #ugly hack: on windows you can escape with ESC, on gtk it is the other side
+                if self.parent.PLATFORM_IS_WIN:
+                    ok = wx.OK
+                    stylemsgbox = wx.OK | wx.CANCEL
                 else:
-                    answer = wx.MessageBox(msg, "DrPython Find", wx.OK | wx.CANCEL | wx.ICON_QUESTION)
-                if answer == wx.OK:
+                    ok = wx.YES
+                    stylemsgbox = wx.YES_NO
+
+                if self.parent.prefs.findreplaceautowrap:
+                    answer = ok
+                else:
+                    answer = wx.MessageBox(msg, "DrPython Find", stylemsgbox | wx.ICON_QUESTION)
+                if answer == ok:
+                    self.findpos = fpos
                     self.stc.GotoPos(self.findpos)
                     if self.backwards:
                         self.DoFindPrevious()
@@ -153,11 +163,18 @@ class drFinder:
             self.lastposition = -1
             if prev > self.targetStart:
                 self.findpos = self.targetStart
-                if self.parent.prefs.findreplaceautowrap:
-                    answer = wx.OK
+                if self.parent.PLATFORM_IS_WIN:
+                    ok = wx.OK
+                    stylemsgbox = wx.OK | wx.CANCEL
                 else:
-                    answer = wx.MessageBox('End of document reached: "' + findtext + '".\nStart again from the beginning?', "DrPython Find", wx.OK | wx.CANCEL | wx.ICON_QUESTION)
-                if answer == wx.OK:
+                    ok = wx.YES
+                    stylemsgbox = wx.YES_NO
+                if self.parent.prefs.findreplaceautowrap:
+                    answer = ok
+                else:
+                    answer = wx.MessageBox('End of document reached: "' + findtext + '".\nStart again from the beginning?', "DrPython Find", stylemsgbox | wx.ICON_QUESTION)
+                
+                if answer == ok:
                     self.stc.GotoPos(self.findpos)
                     self.DoFindNext()
                 else:
@@ -834,7 +851,7 @@ class drFindTextCtrl(wx.ComboBox):
         if self.GetCount() > 0:
             self.Clear()
         l = len(history)
-        self.Append('')
+        #self.Append('')
         x = l - 1
         while x > -1:
             self.Append(history[x])
