@@ -89,14 +89,9 @@ class drMainPanel(wx.Panel):
 
         self.prompt = drSashWindow(self, self.ID_PROMPT, wx.DefaultPosition, wx.DefaultSize, wx.SW_3D)
 
-        self.prompt.SetSashVisible(wx.SASH_TOP, True)
-        self.prompt.SetSashBorder(wx.SASH_TOP, True)
 
         self.document = drSashWindow(self, self.ID_DOCUMENT, wx.DefaultPosition, wx.DefaultSize, wx.SW_3D)
 
-        self.document.SetSashVisible(wx.SASH_BOTTOM, True)
-        self.document.SetSashBorder(wx.SASH_BOTTOM, True)
-
         self.leftsize = self.parent.prefs.sidepanelleftsize
 
         self.left = drSashWindow(self, self.ID_LEFT, wx.DefaultPosition, wx.DefaultSize, wx.SW_3D)
@@ -109,17 +104,6 @@ class drMainPanel(wx.Panel):
 
         self.top = drSashWindow(self, self.ID_TOP, wx.DefaultPosition, wx.DefaultSize, wx.SW_3D)
 
-        self.document.SetSashVisible(wx.SASH_LEFT, True)
-        self.document.SetSashBorder(wx.SASH_LEFT, True)
-        self.document.SetSashVisible(wx.SASH_RIGHT, True)
-        self.document.SetSashBorder(wx.SASH_RIGHT, True)
-        self.document.SetSashVisible(wx.SASH_TOP, True)
-        self.document.SetSashBorder(wx.SASH_TOP, True)
-
-        self.prompt.SetSashVisible(wx.SASH_LEFT, True)
-        self.prompt.SetSashBorder(wx.SASH_LEFT, True)
-        self.prompt.SetSashVisible(wx.SASH_RIGHT, True)
-        self.prompt.SetSashBorder(wx.SASH_RIGHT, True)
 
         self.oldwidth, self.oldheight = 0, 0
 
@@ -140,6 +124,23 @@ class drMainPanel(wx.Panel):
         self.Bind(wx.EVT_SIZE, self.OnSize)
         self.Bind(wx.EVT_SASH_DRAGGED, self.OnSashDrag, id=self.ID_DOCUMENT)
         self.Bind(wx.EVT_SASH_DRAGGED, self.OnSashDrag, id=self.ID_PROMPT)
+        if not parent.PLATFORM_IS_GTK:
+        #if 0:
+            self.document.SetSashVisible(wx.SASH_BOTTOM, True)
+            #self.document.SetSashBorder(wx.SASH_BOTTOM, True)
+            self.prompt.SetSashVisible(wx.SASH_TOP, True)
+            #self.prompt.SetSashBorder(wx.SASH_TOP, True)
+            self.document.SetSashVisible(wx.SASH_LEFT, True)
+            #self.document.SetSashBorder(wx.SASH_LEFT, True)
+            self.document.SetSashVisible(wx.SASH_RIGHT, True)
+            #self.document.SetSashBorder(wx.SASH_RIGHT, True)
+            self.document.SetSashVisible(wx.SASH_TOP, True)
+            #self.document.SetSashBorder(wx.SASH_TOP, True)
+
+            self.prompt.SetSashVisible(wx.SASH_LEFT, True)
+            #self.prompt.SetSashBorder(wx.SASH_LEFT, True)
+            self.prompt.SetSashVisible(wx.SASH_RIGHT, True)
+            #self.prompt.SetSashBorder(wx.SASH_RIGHT, True)
 
     def _getindex(self, Position, Index):
         #Left
@@ -486,11 +487,41 @@ class drDocNotebook(drNotebook):
         drNotebook.__init__(self, parent, id, images, grandparent.OnClose)
 
         self.Bind(wx.EVT_NOTEBOOK_PAGE_CHANGED, self.OnPageChanged)
+        self.Bind(wx.EVT_NAVIGATION_KEY, self.OnNavigationKey)
         self.Bind(wx.EVT_RIGHT_DOWN, self.OnPopUp)
         self.Bind(wx.EVT_LEFT_UP, self.OnSelectTab)
         self.Bind(wx.EVT_LEFT_DCLICK, self.OnLeftDoubleClick)
 
+    def OnNavigationKey(self, event): #only in windows? on gtk, that is apparantly never called.
+        ignorekey = False
+        if self.grandparent.prefs.docignorectrlpageupdown:
+            if wx.GetKeyState(wx.WXK_CONTROL):
+                if wx.GetKeyState(wx.WXK_PAGEUP) or wx.GetKeyState(wx.WXK_PAGEDOWN):
+                    ignorekey = True
+                #if wx.GetKeyState(wx.WXK_TAB):
+                #    ignorekey = True
+        if ignorekey:
+            keycode = 0
+            if wx.GetKeyState(wx.WXK_TAB):
+                keycode = wx.WXK_TAB
+            if wx.GetKeyState(wx.WXK_PAGEUP):
+                keycode = wx.WXK_PAGEUP
+            if wx.GetKeyState(wx.WXK_PAGEDOWN):
+                keycode = wx.WXK_PAGEDOWN
+            evt = wx.KeyEvent()
+            evt.m_controlDown = wx.GetKeyState(wx.WXK_CONTROL)
+            evt.m_keyCode = keycode
+            evt.m_shiftDown = wx.GetKeyState(wx.WXK_SHIFT)
+            evt.SetEventType(wx.wxEVT_KEY_DOWN)
+
+            self.grandparent.txtDocument.GetEventHandler().ProcessEvent(evt)
+        else:
+            event.Skip()
+        
     def OnPageChanged(self, event):
+        if self.grandparent.ignoreevents:
+            return
+
         if not self.grandparent.txtDocumentArray:
             if event is not None:
                 event.Skip()
@@ -505,8 +536,9 @@ class drDocNotebook(drNotebook):
                 event.Skip()
             return
         if self.oldselection < l:
-            self.grandparent.txtDocumentArray[self.oldselection].IsActive = False
-            self.grandparent.txtDocumentArray[self.oldselection].OnModified(None)
+            if len (self.grandparent.txtDocumentArray) > self.oldselection:
+                self.grandparent.txtDocumentArray[self.oldselection].IsActive = False
+                self.grandparent.txtDocumentArray[self.oldselection].OnModified(None)
 
         self.oldselection = i
 
@@ -552,6 +584,7 @@ class drDocNotebook(drNotebook):
         event.Skip()
 
     def SetTab(self):
+        #if not self.IsBeingDeleted(): # is not None: #pydeadobject error
         selection = self.GetSelection()
         if selection != -1:
             self.grandparent.setDocumentTo(selection)
