@@ -66,6 +66,7 @@ def GetPreferencesDictionary():
 ('pythonargs', 'python.arguments', 2),
 ('defaultdirectory', 'default.directory', 2),
 ('enablefeedback', 'enable.feedback', 1),
+('debugmodus', 'debug.modus', 1),
 ('alwayspromptonexit', 'always.prompt.on.exit', 1),
 ('backupfileonsave', 'backup.file.on.save', 1)],
 'File Types': [('extensions[0]', 'filetypes.extensions.python', 0),
@@ -119,6 +120,7 @@ def GetPreferencesDictionary():
 ('docusefileindentation', 'doc.use.file.indentation', 1),
 ('docwhitespaceisvisible', 'doc.whitespace.is.visible.on.startup', 1),
 ('dochighlightcurrentline', 'doc.highlight.current.line', 1),
+('docignorectrlpageupdown', 'doc.ignore.ctrlpageupdown', 1),
 ('doccaretwidth', 'doc.caret.width', 1),
 ('doccommentmode', 'doc.comment.mode', 1),
 ('docusestyles', 'doc.use.styles', 1),
@@ -281,6 +283,7 @@ class drPreferences:
         self.pythonargs = ""
         self.defaultdirectory = programdirectory
         self.enablefeedback = 1
+        wx.GetApp().debugmodus = self.debugmodus = 1
         self.alwayspromptonexit = 0
         self.backupfileonsave = 1
         self.save = 0
@@ -321,6 +324,7 @@ class drPreferences:
         self.docusefileindentation = 1
         self.docwhitespaceisvisible = 0
         self.dochighlightcurrentline = 1
+        self.docignorectrlpageupdown = 0
         self.doccaretwidth = 1
         self.doccommentmode = 0
         self.docusestyles = 1
@@ -550,6 +554,7 @@ class drPreferences:
         if prefsdictionary.has_key(target):
             for Preference in prefsdictionary[target]:
                 self[Preference[0]] = defaults[Preference[0]]
+        wx.GetApp().debugmodus = self['debugmodus']
 
     def Copy(self, target):
         self.platform_is_windows = target.platform_is_windows
@@ -558,4 +563,6 @@ class drPreferences:
         prefsdictionary = GetPreferencesDictionary()
         for Entry in prefsdictionary:
             for Preference in prefsdictionary[Entry]:
-                self[Preference[0]] = target[Preference[0]]
\ No newline at end of file
+                self[Preference[0]] = target[Preference[0]]
+        wx.GetApp().debugmodus = self['debugmodus']
+                
\ No newline at end of file
