@@ -194,6 +194,7 @@ class DocumentPanel(PrefsPanel):
         self.chkWhitespace = wx.CheckBox(self, -1, "")
         self.txtcaretwidth = wx.TextCtrl(self, self.grandparent.ID_DOC_CARET_WIDTH, str(self.grandparent.prefs.doccaretwidth), wx.Point(225, 215), wx.Size(35, -1))
         self.chkhighlightcurrentline = wx.CheckBox(self, -1, "")
+        self.chkignorectrlpageupdown = wx.CheckBox(self, -1, "")
         self.chkuseindentationguides = wx.CheckBox(self, -1, "")
         #Chris McDonough (I added txt prefix, update for local constants)
         self.txtdoclonglinecol = wx.TextCtrl(self, self.grandparent.ID_LONGLINE_COL, str(self.grandparent.prefs.doclonglinecol), wx.Point(225, 215), wx.Size(35, -1))
@@ -220,6 +221,7 @@ class DocumentPanel(PrefsPanel):
         self.Add(self.chkscrollextrapage, "Scroll Extra Page:")
         self.Add(self.txtcaretwidth, "Caret Width:")
         self.Add(self.chkhighlightcurrentline, "Highlight Current Line:")
+        self.Add(self.chkignorectrlpageupdown, "Ignore Ctrl Pageup/down:")
         self.Add(self.raddoccommentmode)
 
         self.SetPanelSizer()
@@ -248,6 +250,7 @@ class DocumentPanel(PrefsPanel):
         self.chkscrollextrapage.SetValue(self.grandparent.prefs.docscrollextrapage)
         self.txtcaretwidth.SetValue(str(self.grandparent.prefs.doccaretwidth))
         self.chkhighlightcurrentline.SetValue(self.grandparent.prefs.dochighlightcurrentline)
+        self.chkignorectrlpageupdown.SetValue(self.grandparent.prefs.docignorectrlpageupdown)
         self.raddoccommentmode.SetSelection(self.grandparent.prefs.doccommentmode)
 
     def Ontxtdoclonglinecol(self, event):
@@ -698,9 +701,9 @@ class GeneralPanel(PrefsPanel):
         except:
             defaultlocale = None
         if defaultlocale is not None:
-            self.encodings = ['', defaultlocale, 'ascii', 'latin-1', 'utf-8', 'utf-16']
+            self.encodings = [defaultlocale, 'ascii', 'latin-1', 'cp1252', 'utf-8', 'utf-16']
         else:
-            self.encodings = ['', 'ascii', 'latin-1', 'utf-8', 'utf-16']
+            self.encodings = ['ascii', 'latin-1', 'cp1252', 'utf-8', 'utf-16']
 
         self.chkrememberwindowsizeandposition = wx.CheckBox(self, -1, "")
         self.chkrememberdialogsizesandpositions = wx.CheckBox(self, -1, "")
@@ -717,6 +720,7 @@ class GeneralPanel(PrefsPanel):
         self.chkcheckindentation = wx.CheckBox(self, -1, "")
         self.txtpythonargs = wx.TextCtrl(self, -1, self.grandparent.prefs.pythonargs, wx.Point(225, 255), wx.Size(55, -1))
         self.chkenablefeedback = wx.CheckBox(self, -1, "")
+        self.chkdebugmodus = wx.CheckBox(self, -1, "")
         self.chkalwayspromptonexit = wx.CheckBox(self, -1, "")
         self.chkbackupfileonsave = wx.CheckBox(self, -1, "")
         self.chkCheckFormat = wx.CheckBox(self, -1, "")
@@ -755,6 +759,7 @@ class GeneralPanel(PrefsPanel):
         self.AddTwoItems(self.txtdefaultcurdirdirectory, self.btnBrowseCurDir)
         self.AddBuffer()
         self.Add(self.chkenablefeedback, "Enable Feedback Messages:")
+        self.Add(self.chkdebugmodus, "Debug Modus:")
         self.Add(self.chkalwayspromptonexit, "Always Prompt On Exit:")
         self.Add(self.chkbackupfileonsave, "Backup File On Save:")
         self.Add(self.btnExportSetup)
@@ -800,6 +805,7 @@ class GeneralPanel(PrefsPanel):
 
         self.txtpythonargs.SetValue(self.grandparent.prefs.pythonargs)
         self.chkenablefeedback.SetValue(self.grandparent.prefs.enablefeedback)
+        self.chkdebugmodus.SetValue(self.grandparent.prefs.debugmodus)
         self.chkalwayspromptonexit.SetValue(self.grandparent.prefs.alwayspromptonexit)
         self.chkbackupfileonsave.SetValue(self.grandparent.prefs.backupfileonsave)
 
@@ -1297,6 +1303,8 @@ class drPrefsDialog(wx.Dialog):
         self.Bind(wx.EVT_BUTTON,  self.OnbtnSave, id=self.ID_SAVE)
 
         parent.LoadDialogSizeAndPosition(self, 'preferencesdialog.sizeandposition.dat')
+        if parent.PLATFORM_IS_GTK: #does not get initially the focus (bug tracker #1903778, "Open Imported Module: focus problem", 29.02.2008: from Jon White, thanks.
+            self.SetFocus()
 
     def OnCloseW(self, event):
         self.parent.SaveDialogSizeAndPosition(self, 'preferencesdialog.sizeandposition.dat')
@@ -1393,6 +1401,8 @@ class drPrefsDialog(wx.Dialog):
         self.prefs.drscriptloadexamples = int(self.pnlDrScript.chkloadexamples.GetValue())
         
         self.prefs.enablefeedback = int(self.pnlGeneral.chkenablefeedback.GetValue())
+        self.prefs.debugmodus = wx.GetApp().debugmodus = int(self.pnlGeneral.chkdebugmodus.GetValue())
+        
         self.prefs.alwayspromptonexit = int(self.pnlGeneral.chkalwayspromptonexit.GetValue())
         self.prefs.backupfileonsave = int(self.pnlGeneral.chkbackupfileonsave.GetValue())
         self.prefs.checkindentation = int(self.pnlGeneral.chkcheckindentation.GetValue())
@@ -1437,6 +1447,7 @@ class drPrefsDialog(wx.Dialog):
         self.prefs.doccaretwidth = int(self.prefs.doccaretwidth)
 
         self.prefs.dochighlightcurrentline = int(self.pnlDocument.chkhighlightcurrentline.GetValue())
+        self.prefs.docignorectrlpageupdown = int(self.pnlDocument.chkignorectrlpageupdown.GetValue())
         #Chris McDonough (I added the txt prefix)
         self.prefs.doclonglinecol = self.pnlDocument.txtdoclonglinecol.GetValue()
         if not self.prefs.doclonglinecol:
