@@ -61,6 +61,7 @@ class DrPrompt(drSTC.DrStyledTextControl):
         self.reTLinenumber = re.compile('line \d+')
 
         self.SetMarginType(1, wx.stc.STC_MARGIN_NUMBER)
+        self.foundvalidline = False
 
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified, id=id)
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
@@ -69,7 +70,7 @@ class DrPrompt(drSTC.DrStyledTextControl):
 
         #Horrible hack by AB:
         #I don't know why, but on Linux wx.EVT_IDLE doesn't work without focus
-        #self.Bind(wx.EVT_IDLE, self.OnIdle)
+        self.Bind(wx.EVT_IDLE, self.OnIdle)
         if wx.Platform == '__WXGTK__':
             self.Bind(wx.EVT_TIMER, self.OnIdle)
             self.t1 = wx.Timer(self)
@@ -77,8 +78,8 @@ class DrPrompt(drSTC.DrStyledTextControl):
         else:
             self.Bind(wx.EVT_IDLE, self.OnIdle)
         #End AB
-
-        self.Bind(wx.EVT_LEFT_DCLICK, self.OnGotoTraceback)
+        self.Bind(wx.EVT_IDLE, self.OnIdle)
+        self.Bind(wx.EVT_LEFT_DCLICK, self.OnGotoSelectedLine)
 
     def _addoutput(self, checkinput=True):
         wx.Usleep(25)
@@ -106,6 +107,10 @@ class DrPrompt(drSTC.DrStyledTextControl):
         in either the stdout or stderr of the current process.
         '''
 
+        # For some reasons, sometimes the python interpreter hangs,
+        # waiting for something to read on stdin.
+        # To solve this problems, we write an extra EOL on stdin
+        self.outputstream.write('\n') #patch by Luca Falavigna - dktrkranz, 07/04/2008, thanks
         text = ''
         while True:
             if text.find(targetoutput) > -1:
@@ -186,30 +191,65 @@ class DrPrompt(drSTC.DrStyledTextControl):
                 self.GotoPos(self.editpoint)
                 self.ScrollToLine(self.LineFromPosition(self.editpoint))
 
-    def OnGotoTraceback(self, event):
+    def OnGotoSelectedLine(self, event):
+        self.foundvalidline = False
+
+        self.grandparent.PPost(self.grandparent.EVT_DRPY_PROMPT_GOTO)
+
         line = self.GetLine(self.GetCurrentLine())
-        fn = self.reTFilename.search(line)
-        ln = self.reTLinenumber.search(line)
-        if (fn is not None) and (ln is not None):
-            filename = fn.group().strip('\"')
-            try:
-                linenumber = int(ln.group().strip('line ')) - 1
-            except:
-                linenumber = 0
-            if os.path.exists(filename):
-                self.grandparent.OpenOrSwitchToFile(filename, editRecentFiles=False)
+
+        #pattern for traceback?
+        if not self.foundvalidline:
+          fn = self.reTFilename.search(line)
+          ln = self.reTLinenumber.search(line)
+          if (fn is not None) and (ln is not None):
+              self.foundvalidline = True
+              self.gotofilename = fn.group().strip('\"')
+              try:
+                  self.gotolinenumber = int(ln.group().strip('line ')) - 1
+              except:
+                  self.gotolinenumber = 0
+        
+        #pattern for pycheckeroutput?
+        if not self.foundvalidline:
+            line = line.replace ('\\', '/')
+            pos = line.find (': ')
+            if pos > -1:
+                s = line[:pos]
+                split = s.rsplit(':', 1)
+                if len (split):
+                    self.foundvalidline = True
+                    self.gotofilename = split[0]
+                    try:
+                        self.gotolinenumber = int(split[1]) - 1
+                    except:
+                        self.gotolinenumber = 0
+                        
+        if self.foundvalidline:
+            if os.path.exists(self.gotofilename):
+                self.grandparent.OpenOrSwitchToFile(self.gotofilename, editRecentFiles=False)
 
                 #self.grandparent.txtDocument.ScrollToLine(linenumber)
                 #patch: [ 1366679 ] Goto Line Should Not Display At Top Of Window
-                top = linenumber - self.grandparent.txtDocument.LinesOnScreen()/2
+                top = self.gotolinenumber - self.grandparent.txtDocument.LinesOnScreen()/2
                 if top < 0:
                     top = 0
                 self.grandparent.txtDocument.ScrollToLine(top)
                 
-                self.grandparent.txtDocument.GotoLine(linenumber)
+                self.grandparent.txtDocument.GotoLine(self.gotolinenumber)
                 self.grandparent.txtDocument.EnsureCaretVisible()
                 self.grandparent.txtDocument.SetFocus()
 
+    def CheckAndCorrectAsciiText(self, text):
+        newtext = str()
+        corrected = False
+        for c in text:
+            if ord(c) > 127:
+                c = '-'
+                corrected = True
+            newtext = newtext + c
+        return newtext, corrected
+    
     def OnKeyDown(self, event):
         if self.pid == -1:
             return
@@ -245,9 +285,13 @@ class DrPrompt(drSTC.DrStyledTextControl):
                         print 'Error Encoding Text'
                         return
 
+                    #ugly hack, but otherwise, drpython crashes
+                    etext, corrected = self.CheckAndCorrectAsciiText(etext)
+                    if corrected:
+                        self.grandparent.ShowMessage("Sorry, only ascii codes until 127 possible.\nOtherwiese the program crashes", "DrPython Error")
+                    
                     self.outputstream.write(etext)
                     self.GotoPos(self.GetLength())
-
                     self._addoutput()
 
                     self.editpoint = self.GetLength()
@@ -294,6 +338,8 @@ class DrPrompt(drSTC.DrStyledTextControl):
             if self.GetCurrentPos() < self.editpoint:
                 self.GotoPos(self.editpoint)
             return
+        if keycode == wx.WXK_RETURN: #patch from merwinb, 2009-0728, thanks (Prompt window scrolls to wrong position)
+            self.GotoPos(self.GetCurrentPos())
         event.Skip()
 
     def OnModified(self, event):
