@@ -326,6 +326,8 @@ class drShortcutsDialog(wx.Dialog):
         self.Bind(wx.EVT_LISTBOX, self.OnSelect, id=self.ID_SHORTCUTS)
 
         self.parent.LoadDialogSizeAndPosition(self, 'shortcutsdialog.sizeandposition.dat')
+        if parent.PLATFORM_IS_GTK: #does not get initially the focus (bug tracker #1903778, "Open Imported Module: focus problem", 29.02.2008: from Jon White, thanks.
+            self.SetFocus()
 
     def LoadPluginShortcutList(self):
         plist = os.listdir(self.parent.pluginsdirectory)
