@@ -240,6 +240,8 @@ class drSeparatorDialog(wx.Dialog):
         self.Bind(wx.EVT_BUTTON,  self.OnbtnSave, id=self.ID_SAVE)
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.txtLabel.Bind(wx.EVT_CHAR, self.OnChar)
+        if parent.PLATFORM_IS_GTK: #does not get initially the focus (bug tracker #1903778, "Open Imported Module: focus problem", 29.02.2008: from Jon White, thanks.
+            self.SetFocus()
 
     def GetLabel(self):
         return '#---' + self.txtLabel.GetValue() + '---' + self.fgPanel.GetValue() + self.bgPanel.GetValue() + '---------------------------------'
@@ -385,7 +387,7 @@ class drSimpleStyleDialog(wx.Dialog):
             if i<0:
                 i=0
             self.boxFonts.Select(i)
-            #self.boxFonts.EnsureVisible(i) # Bug: Doesn't work 
+            #self.boxFonts.EnsureVisible(i) # Bug: Doesn't work
             self.boxFonts.SetFirstItem(i)
             
             
@@ -898,7 +900,7 @@ class drStyleDialog(wx.Dialog):
             if i<0:
                 i=0
             self.boxFonts.Select(i)
-            #self.boxFonts.EnsureVisible(i) # Bug: Doesn't work 
+            #self.boxFonts.EnsureVisible(i) # Bug: Doesn't work
             self.boxFonts.SetFirstItem(i)
         except:
             drScrolledMessageDialog.ShowMessage(self, ("Something awful happened trying to \nset the font to the default."), "Error")
