@@ -193,6 +193,8 @@ class DrText(drSTC.DrStyledTextControl):
         return "Untitled " + str(self.untitlednumber)
 
     def OnModified(self, event):
+        if self.grandparent.disableeventhandling:
+            return
         if self.DynamicScript:
             return
         if not self.IsSplitView:
@@ -204,27 +206,28 @@ class DrText(drSTC.DrStyledTextControl):
                 self.modified = modify
                 if self.modified:
                     if self.IsActive:
-                        self.notebookparent.SetPageImage(self.targetPosition, 3)
+                        pimageidx = 3
                     else:
-                        self.notebookparent.SetPageImage(self.targetPosition, 1)
-                    if not self.filename:
-                        self.notebookparent.SetPageText(self.targetPosition, "Untitled " + str(self.untitlednumber))
-                        self.grandparent.SetTitle("DrPython - Untitled " + str(self.untitlednumber) + ' [Modified]')
-                    elif self.grandparent.GetTitle().find('[Modified]') == -1:
-                        self.notebookparent.SetPageText(self.targetPosition, os.path.basename(self.filename))
-                        self.grandparent.SetTitle("DrPython - " + self.filename + " [Modified]")
+                        pimageidx = 1
                 else:
                     if self.IsActive:
-                        self.notebookparent.SetPageImage(self.targetPosition, 2)
+                        pimageidx = 2
                     else:
-                        self.notebookparent.SetPageImage(self.targetPosition, 0)
+                        pimageidx = 0
                     self.SetSavePoint()
-                    if not self.filename:
-                        self.notebookparent.SetPageText(self.targetPosition, "Untitled " + str(self.untitlednumber))
-                        self.grandparent.SetTitle("DrPython - Untitled " + str(self.untitlednumber))
-                    else:
-                        self.notebookparent.SetPageText(self.targetPosition, os.path.basename(self.filename))
-                        self.grandparent.SetTitle("DrPython - " + self.filename)
+
+                self.notebookparent.SetPageImage(self.targetPosition, pimageidx)
+                if not self.filename:
+                    title = "DrPython - Untitled " + str(self.untitlednumber)
+                    pagetext = "Untitled " + str(self.untitlednumber)
+                else:
+                    title = "DrPython - " + self.filename
+                    pagetext = os.path.basename(self.filename)
+                if self.modified:
+                    title += '[Modified]'
+                #wx.CallAfter(self.grandparent.SetTitle, title) #workaround one for gtk, 15.03.2008, else segmentation fault
+                self.grandparent.SetTitle(title)
+                self.notebookparent.SetPageText(self.targetPosition, pagetext)
 
         if self.grandparent.prefs.docupdateindentation:
             #If deleting text, or undo/redo:
@@ -290,10 +293,12 @@ class DrText(drSTC.DrStyledTextControl):
             ovrstring = "OVR"
         else:
             ovrstring = "INS"
-
-        self.grandparent.SetStatusText(("Line: %(line)s, Col: %(col)s   %(mode)s   %(ovrstring)s   %(ind)s" \
+        statustext = "Line: %(line)s, Col: %(col)s   %(mode)s   %(ovrstring)s   %(ind)s" \
         % {"line": self.GetCurrentLine()+1, "col": self.GetColumn(self.GetCurrentPos()), \
-        "mode": eolmodestr, "ovrstring": ovrstring, "ind": self.indentationstring}), 1)
+        "mode": eolmodestr, "ovrstring": ovrstring, "ind": self.indentationstring}
+        #reason gtk ; workaround tow for gtk, 15.03.2008, else segmentation fault
+        #wx.CallAfter (self.grandparent.SetStatusText,statustext, 1)
+        self.grandparent.SetStatusText(statustext, 1)
 
         if event is not None:
             event.Skip()
