@@ -11,7 +11,7 @@ pathtoterminal = "/usr/bin/X11/rxvt"
 termarg = "-e"
 withargs = ""
 if DrScript.VariableExists("RunInTerminalArgs"):
-	withargs = DrScript.RunInTerminalArgs
-d = wxTextEntryDialog(DrFrame, "Arguments:", "Set Arguments For Run In Terminal", withargs)
-if (d.ShowModal() == wxID_OK):
-	DrScript.RunInTerminalArgs = d.GetValue()
\ No newline at end of file
+    withargs = DrScript.RunInTerminalArgs
+d = wx.TextEntryDialog(DrFrame, "Arguments:", "Set Arguments For Run In Terminal", withargs)
+if d.ShowModal() == wx.ID_OK:
+    DrScript.RunInTerminalArgs = d.GetValue()
\ No newline at end of file
